@@ -1,18 +1,19 @@
 import asyncio
-import discord.ext
 import errno
 import os
 import signal
 from functools import wraps
 from typing import Any, AsyncGenerator, Callable, Coroutine, Iterable, Mapping, Optional, TypeVar
 
+import discord.ext
+
 Decorator = Callable[[Callable], Callable]
 DecoratorFunction = Callable[..., Decorator]
 
 R = TypeVar("R")
 
 
-def timeout_after(seconds: int = 10,
+def timeout_after(seconds: float = 10,
                   error_message: str = os.strerror(errno.ETIME)) \
         -> Decorator:
     """A decorator to give a timeout to a synchronous function"""
