@@ -110,6 +110,8 @@ AWAKENING_ID_TO_EMOJI_NAME_MAP = {
     104: 'oe_heart_super',
     105: 'misc_sb_minus',
     106: 'misc_levitate',
+    107: 'misc_comboboost_super',
+    108: 'l_attack_super',
 }
 
 AWAKENING_RESTRICTED_LATENT_VALUE_TO_EMOJI_NAME_MAP = {
