@@ -31,6 +31,9 @@ SKYOZORA_TEMPLATE = 'http://pad.skyozora.com/pets/{}'
 ILMINA_TEMPLATE = 'https://ilmina.com/#/CARD/{}'
 PADINDEX_TEMPLATE = 'https://pad.chesterip.cc/{}'
 
+SHEETS_TEMPLATE = 'https://docs.google.com/spreadsheets/d/1EoZJ3w5xsXZ67kmarLE4vfrZSIIIAfj04HXeZVST3eY' \
+                  '/pub?gid={}&single=true&output=csv'
+
 
 class MonsterImage:
     @staticmethod
@@ -104,3 +107,14 @@ class MonsterLink:
             return MonsterLink.padindex(m)
         else:
             return MonsterLink.ilmina(m)
+
+
+class SheetsTab:
+    CARDNAME_OVERRIDE = 0
+    TREENAME_OVERRIDES = 2070615818
+    CARD_MODIFIER_OVERRIDE = 2089525837
+    TREE_MODIFIER_OVERRIDE = 1372419168
+    CONTENT_TOKEN_ALIAS = 1229125459
+    SERIES_OVERRIDES = 959933643
+    AWOKEN_SKILL = 1063132392
+    DUNGEONS = 1224404198
